Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(46)

Unified Diff: tests/MipMapTest.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/MetaDataTest.cpp ('k') | tests/OSPathTest.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/MipMapTest.cpp
diff --git a/tests/MipMapTest.cpp b/tests/MipMapTest.cpp
index c8396effa6ea133721fc9397c8d56d46927bb652..5e5e894870f813b2869723025abee595b9a84828 100644
--- a/tests/MipMapTest.cpp
+++ b/tests/MipMapTest.cpp
@@ -11,7 +11,7 @@
#include "Test.h"
static void make_bitmap(SkBitmap* bm, SkRandom& rand) {
// for now, Build needs a min size of 2, otherwise it will return NULL.
// should fix that to support 1 X N, where N > 1 to return non-null.
int w = 2 + rand.nextU() % 1000;
int h = 2 + rand.nextU() % 1000;
@@ -25,10 +25,10 @@ DEF_TEST(MipMap, reporter) {
for (int i = 0; i < 500; ++i) {
make_bitmap(&bm, rand);
- SkAutoTUnref<SkMipMap> mm(SkMipMap::Build(bm, NULL));
+ SkAutoTUnref<SkMipMap> mm(SkMipMap::Build(bm, nullptr));
- REPORTER_ASSERT(reporter, !mm->extractLevel(SK_Scalar1, NULL));
- REPORTER_ASSERT(reporter, !mm->extractLevel(SK_Scalar1 * 2, NULL));
+ REPORTER_ASSERT(reporter, !mm->extractLevel(SK_Scalar1, nullptr));
+ REPORTER_ASSERT(reporter, !mm->extractLevel(SK_Scalar1 * 2, nullptr));
SkMipMap::Level prevLevel;
sk_bzero(&prevLevel, sizeof(prevLevel));
« no previous file with comments | « tests/MetaDataTest.cpp ('k') | tests/OSPathTest.cpp » ('j') | no next file with comments »
@@ -11,7 +11,7 @@
#include "Test.h"
static void make_bitmap(SkBitmap* bm, SkRandom& rand) {
- // for now, Build needs a min size of 2, otherwise it will return NULL.
+ // for now, Build needs a min size of 2, otherwise it will return nullptr.
// should fix that to support 1 X N, where N > 1 to return non-null.
int w = 2 + rand.nextU() % 1000;

Powered by Google App Engine
This is Rietveld 408576698